#' Datasets
#' geneList entrez gene list with decreasing fold change value
#'
#'
#' @name Datasets
#' @aliases geneList
#' @docType data
#' @keywords datasets
NULL

#' Datasets
#' Differential expression analysis result of GSE42872
#'
#'
#' @name Datasets
#' @aliases deg
#' @docType data
#' @keywords datasets
NULL

#' Datasets
#' msig_species contains msigdb species information
#'
#'
#' @name Datasets
#' @aliases msig_org
#' @docType data
#' @keywords datasets
NULL

#' Datasets
#' msig_category contains msigdb category information
#'
#' @name Datasets
#' @aliases msig_category
#' @docType data
#' @keywords datasets
NULL

#' Datasets
#' biocOrg_name contains organism name of bioconductor
#'
#' @name Datasets
#' @aliases biocOrg_name
#' @docType data
#' @keywords datasets
NULL

#' Datasets
#' keggOrg_name contains organism name of KEGG
#' https://www.genome.jp/kegg/catalog/org_list.html
#'
#' @name Datasets
#' @aliases keggOrg_name
#' @docType data
#' @keywords datasets
NULL

#' Datasets
#' ensOrg_name contains organism name of ensembl
#'
#'
#' @name Datasets
#' @aliases ensOrg_name
#' @docType data
#' @keywords datasets
NULL
